/*
 * File         : DBmain.java
 * Author       : Tomasz Stachowiak
 * Created      : Fri Jun 20 14:30:06 1997
 * Revision     : $Revision$
 * Updated      : $Date$
 * Copyright: Northeast Parallel Architectures Center
 *            at Syracuse University 1997
 */

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.sql.*;

class DBmain extends Frame implements ActionListener, ItemListener {

	//{{DECLARE_CONTROLS
	java.awt.Panel querypanel;
	java.awt.TextField ses_name;
	java.awt.Label label1;
	java.awt.Label label2;
	java.awt.Label label3;
	java.awt.TextField ses_date;
	java.awt.Checkbox active;
	CheckboxGroup Group1;
	java.awt.Button submit;
	java.awt.Panel ses_panel;
	java.awt.Label label4;
	java.awt.List ses_list;
	java.awt.Panel parts_panel;
	java.awt.List parts_list;
	java.awt.Label label5;
	java.awt.Panel apps_panel;
	java.awt.List apps_list;
	java.awt.Label label6;
	java.awt.Button exit;


  NCSdatabase db;
  QueryControl ctrl;
  Vector sessions;
  Session ses_select;

  public DBmain() {
    //{{INIT_CONTROLS
    setLayout(null);
    addNotify();
    setSize(getInsets().left + getInsets().right + 445,getInsets().top 
           + getInsets().bottom + 432);
    querypanel = new java.awt.Panel();
    querypanel.setLayout(null);
    querypanel.setBounds(getInsets().left + 12,getInsets().top + 12,206,181);
    add(querypanel);
    ses_name = new java.awt.TextField();
    ses_name.setBounds(48,24,156,36);
    querypanel.add(ses_name);
    label1 = new java.awt.Label("Session query:");
    label1.setBounds(0,-12,149,36);
    querypanel.add(label1);
    label2 = new java.awt.Label("Name:");
    label2.setBounds(0,24,63,29);
    querypanel.add(label2);
    label3 = new java.awt.Label("Date:");
    label3.setBounds(0,72,48,29);
    querypanel.add(label3);
    ses_date = new java.awt.TextField();
    ses_date.setBounds(48,72,84,36);
    querypanel.add(ses_date);
    Group1 = new CheckboxGroup();
    active = new java.awt.Checkbox("active");
    active.setBounds(48,120,128,21);
    querypanel.add(active);

    submit = new java.awt.Button("Submit");
    submit.setBounds(48,156,99,24);
    querypanel.add(submit);
    submit.addActionListener(this);

    ses_panel = new java.awt.Panel();
    ses_panel.setLayout(null);
    ses_panel.setBounds(getInsets().left + 228,getInsets().top + 0,212,204);
    add(ses_panel);
    label4 = new java.awt.Label("Sessions:");
    label4.setBounds(0,0,149,36);
    ses_panel.add(label4);

    ses_list = new java.awt.List(0,false);
    ses_panel.add(ses_list);
    ses_list.setBounds(12,48,198,123);
    ses_list.addItemListener(this);

    parts_panel = new java.awt.Panel();
    parts_panel.setLayout(null);
    parts_panel.setBounds(getInsets().left + 12,getInsets().top + 204,212,180);
    add(parts_panel);
    parts_list = new java.awt.List(0,false);
    parts_panel.add(parts_list);
    parts_list.setBounds(12,48,192,110);
    parts_list.addItemListener(this);

    label5 = new java.awt.Label("Participants:");
    label5.setBounds(0,0,149,36);
    parts_panel.add(label5);
    apps_panel = new java.awt.Panel();
    apps_panel.setLayout(null);
    apps_panel.setBounds(getInsets().left + 228,getInsets().top + 204,212,180);
    add(apps_panel);
    apps_list = new java.awt.List(0,false);
    apps_panel.add(apps_list);
    apps_list.setBounds(12,48,192,110);
    apps_list.addItemListener(this);

    label6 = new java.awt.Label("Applications:");
    label6.setBounds(0,0,149,36);
    apps_panel.add(label6);
    exit = new java.awt.Button("Exit");
    exit.setBounds(getInsets().left + 168,getInsets().top + 396,116,27);
    add(exit);
    exit.addActionListener(this);

    setTitle("BuenaVista Database System");
    setResizable(false);
  }


  class DWAdapter extends WindowAdapter {
    public void windowClosing(WindowEvent event) {
      exit();
    }
  }

  public void actionPerformed(ActionEvent event) {
    
    if (event.getSource() == submit) {
      submit();
    }
    if (event.getSource() == exit) {
      exit();
    }
  }

  public void itemStateChanged(ItemEvent event) {

    if (event.getStateChange() == ItemEvent.SELECTED) {
      

      if(event.getSource() == ses_list) {

	ses_select = (Session)sessions.elementAt(ses_list.getSelectedIndex());
	
	ses_select.retrieveParts();
	parts_list.removeAll();
	for (Enumeration e = ses_select.getParts().elements() 
	     ; e.hasMoreElements() ;) {
	  
	  parts_list.add(e.nextElement().toString());
	}
	
	ses_select.retrieveApps();
	apps_list.removeAll();
	for (Enumeration e = ses_select.getApps().elements() 
	       ; e.hasMoreElements() ;) {
	
	  apps_list.add(e.nextElement().toString());
	}
      }

      if(event.getSource() == parts_list) {

	System.out.println("Participants list selection");
      }

      if(event.getSource() == apps_list) {

	System.out.println("Applications list selection");
      }

    }
  }

  public void exit() {

    System.out.println("Exitting...");
    db.close();
    System.exit(0);
  }

  public void init() {

    db = new NCSdatabase();
    
    try {

      db.init();

      ctrl = new QueryControl(db);
    } catch (Exception e) {

      System.out.println("DBmain: " + e);
    }
  }


  public void submit() {

    String name = ses_name.getText();
    String date = ses_date.getText();
    boolean act = active.getState();
    int activ = 0;

    

    if(name.length() == 0) 
      name = null;

    if(date.length() == 0)
      date = null;

    if(act)
      activ = 1;
    else
      activ = 0;

    ctrl.retrieveSessions(name, date, activ);

    sessions = ctrl.getSessions();

    ses_list.removeAll();

    for (Enumeration e = sessions.elements() ; e.hasMoreElements() ;) {

      ses_list.add(e.nextElement().toString());
      
    } 
  }


  public static void main(String argv[]) {
    DBmain f = new DBmain();
    //f.setSize(170, 170);
    f.show();
    f.init();
  }
}
